@@ -3,7 +3,7 @@
 
 /*
  * Copyright 2011-2018 Brad Lanam, Walnut Creek, CA
- * Copyright 2023 Brad Lanam, Pleasant Hill, CA
+ * Copyright 2023-2024 Brad Lanam, Pleasant Hill, CA
  */
 
 #if defined(TEST_GETOPTN)
@@ -18,6 +18,10 @@
 # include <sys/types.h>
 #endif
 
+# if defined (__cplusplus) || defined (c_plusplus)
+extern "C" {
+# endif
+
 #if ! defined (TRUE)
 # define TRUE             1
 #endif
@@ -60,4 +64,8 @@ typedef struct {
 extern int getoptn (int style, int argc, const char * const argv [],
       Size_t optcount, getoptn_opt_t opts [], int *errorCount);
 
+# if defined (__cplusplus) || defined (c_plusplus)
+}
+# endif
+
 #endif /*DI_INC_GETOPTN_H_ */
